@@ -80,7 +80,8 @@ class PyodbcConnectionMock(object):
         self._searchescape = searchescape
         self._autocommit = (properties.get('autocommit', 'false') == 'true')
         self._readonly = (properties.get('readonly', 'false') == 'true')
-        self._timeout = int(properties.get('timeout', '0'))
+        self._timeoutConnect = int(properties.get('timeout', '0'))
+        self._timeout = 0
         self._unicode_results = (properties.get('unicode_results', 'false') == 'true')
         self._isClosed = False
         self._cursors = []
