@@ -56,12 +56,14 @@ class PyodbcResource(object):
         properties = dict((k.lower(), v) for k, v in (x.split('=', 1) for x in resourceString.split(';') if x))
 
         # Create the connection
+        timeout = int(properties.get('timeout', 0))
         self._connection = pyodbc.connect(resourceString,
                                           ansi = (properties.get('ansi', 'false').lower() == 'true'),
                                           autocommit = (properties.get('autocommit', 'false') == 'true'),
                                           readonly = (properties.get('readonly', 'false') == 'true'),
-                                          timeout = int(properties.get('timeout', '0')),
+                                          timeout = timeout,
                                           unicode_results = (properties.get('unicode_results', 'false') == 'true'))
+        self.timeout = timeout
 
     @property
     def autocommit(self):
